qtcore_mapping = {
    'QAbstractAnimation': 'PySide6.QtCore', 'QAbstractEventDispatcher': 'PySide6.QtCore',
    'QAbstractItemModel': 'PySide6.QtCore', 'QAbstractListModel': 'PySide6.QtCore',
    'QAbstractNativeEventFilter': 'PySide6.QtCore', 'QAbstractProxyModel': 'PySide6.QtCore',
    'QAbstractTableModel': 'PySide6.QtCore', 'QAnimationGroup': 'PySide6.QtCore',
    'QBasicTimer': 'PySide6.QtCore', 'QBitArray': 'PySide6.QtCore',
    'QBuffer': 'PySide6.QtCore', 'QByteArray': 'PySide6.QtCore',
    'QByteArrayMatcher': 'PySide6.QtCore', 'QCalendar': 'PySide6.QtCore',
    'QChildEvent': 'PySide6.QtCore', 'QCollator': 'PySide6.QtCore',
    'QCollatorSortKey': 'PySide6.QtCore', 'QCommandLineOption': 'PySide6.QtCore',
    'QCommandLineParser': 'PySide6.QtCore', 'QConcatenateTablesProxyModel': 'PySide6.QtCore',
    'QCoreApplication': 'PySide6.QtCore', 'QCryptographicHash': 'PySide6.QtCore',
    'QDate': 'PySide6.QtCore', 'QDateTime': 'PySide6.QtCore',
    'QDeadlineTimer': 'PySide6.QtCore', 'QDir': 'PySide6.QtCore',
    'QDirIterator': 'PySide6.QtCore', 'QDynamicPropertyChangeEvent': 'PySide6.QtCore',
    'QEasingCurve': 'PySide6.QtCore', 'QElapsedTimer': 'PySide6.QtCore',
    'QEvent': 'PySide6.QtCore', 'QEventLoop': 'PySide6.QtCore',
    'QEventLoopLocker': 'PySide6.QtCore', 'QException': 'PySide6.QtCore',
    'QFile': 'PySide6.QtCore', 'QFileInfo': 'PySide6.QtCore',
    'QFileSelector': 'PySide6.QtCore', 'QFileSystemWatcher': 'PySide6.QtCore',
    'QFinalState': 'PySide6.QtCore', 'QFuture': 'PySide6.QtCore',
    'QFutureIterator': 'PySide6.QtCore', 'QFutureSynchronizer': 'PySide6.QtCore',
    'QFutureWatcher': 'PySide6.QtCore', 'QGenericArgument': 'PySide6.QtCore',
    'QGenericReturnArgument': 'PySide6.QtCore', 'QHistoryState': 'PySide6.QtCore',
    'QIODevice': 'PySide6.QtCore', 'QItemSelection': 'PySide6.QtCore',
    'QItemSelectionModel': 'PySide6.QtCore', 'QItemSelectionRange': 'PySide6.QtCore',
    'QJsonArray': 'PySide6.QtCore', 'QJsonDocument': 'PySide6.QtCore',
    'QJsonObject': 'PySide6.QtCore', 'QJsonParseError': 'PySide6.QtCore',
    'QJsonValue': 'PySide6.QtCore', 'QKeyEventTransition': 'PySide6.QtCore',
    'QLine': 'PySide6.QtCore', 'QLineF': 'PySide6.QtCore',
    'QLocale': 'PySide6.QtCore', 'QMargins': 'PySide6.QtCore',
    'QMarginsF': 'PySide6.QtCore', 'QMessageAuthenticationCode': 'PySide6.QtCore',
    'QMessageLogContext': 'PySide6.QtCore', 'QMetaClassInfo': 'PySide6.QtCore',
    'QMetaEnum': 'PySide6.QtCore', 'QMetaMethod': 'PySide6.QtCore',
    'QMetaObject': 'PySide6.QtCore', 'QMetaProperty': 'PySide6.QtCore',
    'QMimeData': 'PySide6.QtCore', 'QMimeDatabase': 'PySide6.QtCore',
    'QMimeType': 'PySide6.QtCore', 'QModelIndex': 'PySide6.QtCore',
    'QMutex': 'PySide6.QtCore', 'QMutexLocker': 'PySide6.QtCore',
    'QObject': 'PySide6.QtCore', 'QOperatingSystemVersion': 'PySide6.QtCore',
    'QParallelAnimationGroup': 'PySide6.QtCore', 'QPauseAnimation': 'PySide6.QtCore',
    'QPersistentModelIndex': 'PySide6.QtCore', 'QPluginLoader': 'PySide6.QtCore',
    'QPoint': 'PySide6.QtCore', 'QPointF': 'PySide6.QtCore',
    'QProcess': 'PySide6.QtCore', 'QProcessEnvironment': 'PySide6.QtCore',
    'QPropertyAnimation': 'PySide6.QtCore', 'QReadLocker': 'PySide6.QtCore',
    'QReadWriteLock': 'PySide6.QtCore', 'QRect': 'PySide6.QtCore',
    'QRectF': 'PySide6.QtCore', 'QRegExp': 'PySide6.QtCore',
    'QRegularExpression': 'PySide6.QtCore', 'QRegularExpressionMatch': 'PySide6.QtCore',
    'QRegularExpressionMatchIterator': 'PySide6.QtCore', 'QResource': 'PySide6.QtCore',
    'QRunnable': 'PySide6.QtCore', 'QSaveFile': 'PySide6.QtCore',
    'QSemaphore': 'PySide6.QtCore', 'QSemaphoreReleaser': 'PySide6.QtCore',
    'QSequentialAnimationGroup': 'PySide6.QtCore', 'QSettings': 'PySide6.QtCore',
    'QSharedMemory': 'PySide6.QtCore', 'QSignalBlocker': 'PySide6.QtCore',
    'QSignalMapper': 'PySide6.QtCore', 'QSize': 'PySide6.QtCore',
    'QSizeF': 'PySide6.QtCore', 'QSocketNotifier': 'PySide6.QtCore',
    'QSortFilterProxyModel': 'PySide6.QtCore', 'QStandardPaths': 'PySide6.QtCore',
    'QState': 'PySide6.QtCore', 'QStateMachine': 'PySide6.QtCore',
    'QStorageInfo': 'PySide6.QtCore', 'QStringListModel': 'PySide6.QtCore',
    'QSysInfo': 'PySide6.QtCore', 'QSystemSemaphore': 'PySide6.QtCore',
    'QTemporaryDir': 'PySide6.QtCore', 'QTemporaryFile': 'PySide6.QtCore',
    'QTextBoundaryFinder': 'PySide6.QtCore', 'QTextStream': 'PySide6.QtCore',
    'QThread': 'PySide6.QtCore', 'QThreadPool': 'PySide6.QtCore',
    'QThreadStorage': 'PySide6.QtCore', 'QTime': 'PySide6.QtCore',
    'QTimeLine': 'PySide6.QtCore', 'QTimer': 'PySide6.QtCore',
    'QTimerEvent': 'PySide6.QtCore', 'QTranslator': 'PySide6.QtCore',
    'QUrl': 'PySide6.QtCore', 'QUrlQuery': 'PySide6.QtCore',
    'QVariantAnimation': 'PySide6.QtCore', 'QVersionNumber': 'PySide6.QtCore',
    'QWaitCondition': 'PySide6.QtCore', 'QWriteLocker': 'PySide6.QtCore',
    'QXmlStreamAttribute': 'PySide6.QtCore', 'QXmlStreamAttributes': 'PySide6.QtCore',
    'QXmlStreamEntityDeclaration': 'PySide6.QtCore', 'QXmlStreamEntityResolver': 'PySide6.QtCore',
    'QXmlStreamNamespaceDeclaration': 'PySide6.QtCore', 'QXmlStreamNotationDeclaration': 'PySide6.QtCore',
    'QXmlStreamReader': 'PySide6.QtCore', 'QXmlStreamWriter': 'PySide6.QtCore'
}



qtgui_mapping = {
    'QAbstractFileIconProvider': 'PySide6.QtGui', 'QAbstractTextDocumentLayout': 'PySide6.QtGui',
    'QAction': 'PySide6.QtGui', 'QActionEvent': 'PySide6.QtGui',
    'QBackingStore': 'PySide6.QtGui', 'QBitmap': 'PySide6.QtGui',
    'QBrush': 'PySide6.QtGui', 'QClipboard': 'PySide6.QtGui',
    'QCloseEvent': 'PySide6.QtGui', 'QColor': 'PySide6.QtGui',
    'QConicalGradient': 'PySide6.QtGui', 'QContextMenuEvent': 'PySide6.QtGui',
    'QCursor': 'PySide6.QtGui', 'QDesktopServices': 'PySide6.QtGui',
    'QDoubleValidator': 'PySide6.QtGui', 'QDrag': 'PySide6.QtGui',
    'QDragEnterEvent': 'PySide6.QtGui', 'QDragLeaveEvent': 'PySide6.QtGui',
    'QDragMoveEvent': 'PySide6.QtGui', 'QDropEvent': 'PySide6.QtGui',
    'QEnterEvent': 'PySide6.QtGui', 'QExposeEvent': 'PySide6.QtGui',
    'QFileOpenEvent': 'PySide6.QtGui', 'QFocusEvent': 'PySide6.QtGui',
    'QFont': 'PySide6.QtGui', 'QFontDatabase': 'PySide6.QtGui',
    'QFontInfo': 'PySide6.QtGui', 'QFontMetrics': 'PySide6.QtGui',
    'QFontMetricsF': 'PySide6.QtGui', 'QGestureEvent': 'PySide6.QtGui',
    'QGlyphRun': 'PySide6.QtGui', 'QGradient': 'PySide6.QtGui',
    'QGuiApplication': 'PySide6.QtGui', 'QHelpEvent': 'PySide6.QtGui',
    'QHideEvent': 'PySide6.QtGui', 'QHoverEvent': 'PySide6.QtGui',
    'QIcon': 'PySide6.QtGui', 'QIconDragEvent': 'PySide6.QtGui',
    'QIconEngine': 'PySide6.QtGui', 'QImage': 'PySide6.QtGui',
    'QImageIOHandler': 'PySide6.QtGui', 'QImageReader': 'PySide6.QtGui',
    'QImageWriter': 'PySide6.QtGui', 'QInputEvent': 'PySide6.QtGui',
    'QInputMethodEvent': 'PySide6.QtGui', 'QIntValidator': 'PySide6.QtGui',
    'QKeyEvent': 'PySide6.QtGui', 'QKeySequence': 'PySide6.QtGui',
    'QLinearGradient': 'PySide6.QtGui', 'QMatrix4x4': 'PySide6.QtGui',
    'QMouseEvent': 'PySide6.QtGui', 'QMoveEvent': 'PySide6.QtGui',
    'QMovie': 'PySide6.QtGui', 'QNativeGestureEvent': 'PySide6.QtGui',
    'QOffscreenSurface': 'PySide6.QtGui', 'QOpenGLContext': 'PySide6.QtGui',
    'QOpenGLContextGroup': 'PySide6.QtGui', 'QOpenGLExtraFunctions': 'PySide6.QtGui',
    'QOpenGLFunctions': 'PySide6.QtGui', 'QOpenGLTexture': 'PySide6.QtGui',
    'QPageLayout': 'PySide6.QtGui', 'QPageSize': 'PySide6.QtGui',
    'QPagedPaintDevice': 'PySide6.QtGui', 'QPaintDevice': 'PySide6.QtGui',
    'QPaintEngine': 'PySide6.QtGui', 'QPaintEngineState': 'PySide6.QtGui',
    'QPaintEvent': 'PySide6.QtGui', 'QPainter': 'PySide6.QtGui',
    'QPainterPath': 'PySide6.QtGui', 'QPalette': 'PySide6.QtGui',
    'QPdfWriter': 'PySide6.QtGui', 'QPen': 'PySide6.QtGui',
    'QPicture': 'PySide6.QtGui', 'QPixelFormat': 'PySide6.QtGui',
    'QPixmap': 'PySide6.QtGui', 'QPixmapCache': 'PySide6.QtGui',
    'QPolygon': 'PySide6.QtGui', 'QPolygonF': 'PySide6.QtGui',
    'QRadialGradient': 'PySide6.QtGui', 'QRasterWindow': 'PySide6.QtGui',
    'QRawFont': 'PySide6.QtGui', 'QRegExpValidator': 'PySide6.QtGui',
    'QRegion': 'PySide6.QtGui', 'QRegularExpressionValidator': 'PySide6.QtGui',
    'QResizeEvent': 'PySide6.QtGui', 'QScreen': 'PySide6.QtGui',
    'QScrollEvent': 'PySide6.QtGui', 'QScrollPrepareEvent': 'PySide6.QtGui',
    'QSessionManager': 'PySide6.QtGui', 'QShortcut': 'PySide6.QtGui',
    'QShortcutEvent': 'PySide6.QtGui', 'QShowEvent': 'PySide6.QtGui',
    'QStandardItem': 'PySide6.QtGui', 'QStandardItemModel': 'PySide6.QtGui',
    'QStaticText': 'PySide6.QtGui', 'QStatusTipEvent': 'PySide6.QtGui',
    'QStyleHints': 'PySide6.QtGui', 'QSurface': 'PySide6.QtGui',
    'QSurfaceFormat': 'PySide6.QtGui', 'QSyntaxHighlighter': 'PySide6.QtGui',
    'QTabletEvent': 'PySide6.QtGui', 'QTextBlock': 'PySide6.QtGui',
    'QTextBlockFormat': 'PySide6.QtGui', 'QTextBlockGroup': 'PySide6.QtGui',
    'QTextBlockUserData': 'PySide6.QtGui', 'QTextCharFormat': 'PySide6.QtGui',
    'QTextCursor': 'PySide6.QtGui', 'QTextDocument': 'PySide6.QtGui',
    'QTextDocumentFragment': 'PySide6.QtGui', 'QTextDocumentWriter': 'PySide6.QtGui',
    'QTextFormat': 'PySide6.QtGui', 'QTextFragment': 'PySide6.QtGui',
    'QTextFrame': 'PySide6.QtGui', 'QTextFrameFormat': 'PySide6.QtGui',
    'QTextImageFormat': 'PySide6.QtGui', 'QTextLayout': 'PySide6.QtGui',
    'QTextLength': 'PySide6.QtGui', 'QTextLine': 'PySide6.QtGui',
    'QTextList': 'PySide6.QtGui', 'QTextListFormat': 'PySide6.QtGui',
    'QTextObject': 'PySide6.QtGui', 'QTextObjectInterface': 'PySide6.QtGui',
    'QTextOption': 'PySide6.QtGui', 'QTextTable': 'PySide6.QtGui',
    'QTextTableCell': 'PySide6.QtGui', 'QTextTableCellFormat': 'PySide6.QtGui',
    'QTextTableFormat': 'PySide6.QtGui', 'QTouchEvent': 'PySide6.QtGui',
    'QTransform': 'PySide6.QtGui', 'QUndoCommand': 'PySide6.QtGui',
    'QUndoGroup': 'PySide6.QtGui', 'QUndoStack': 'PySide6.QtGui',
    'QValidator': 'PySide6.QtGui', 'QVector2D': 'PySide6.QtGui',
    'QVector3D': 'PySide6.QtGui', 'QVector4D': 'PySide6.QtGui',
    'QWhatsThisClickedEvent': 'PySide6.QtGui', 'QWheelEvent': 'PySide6.QtGui',
    'QWindow': 'PySide6.QtGui', 'QWindowStateChangeEvent': 'PySide6.QtGui'
}



qtwidgets_mapping = {
    'QAbstractButton': 'PySide6.QtWidgets', 'QAbstractGraphicsShapeItem': 'PySide6.QtWidgets',
    'QAbstractItemDelegate': 'PySide6.QtWidgets', 'QAbstractItemView': 'PySide6.QtWidgets',
    'QAbstractScrollArea': 'PySide6.QtWidgets', 'QAbstractSlider': 'PySide6.QtWidgets',
    'QAbstractSpinBox': 'PySide6.QtWidgets', 'QAccessibleWidget': 'PySide6.QtWidgets',
    'QApplication': 'PySide6.QtWidgets', 'QBoxLayout': 'PySide6.QtWidgets',
    'QButtonGroup': 'PySide6.QtWidgets', 'QCalendarWidget': 'PySide6.QtWidgets',
    'QCheckBox': 'PySide6.QtWidgets', 'QColorDialog': 'PySide6.QtWidgets',
    'QColormap': 'PySide6.QtWidgets', 'QColumnView': 'PySide6.QtWidgets',
    'QComboBox': 'PySide6.QtWidgets', 'QCommandLinkButton': 'PySide6.QtWidgets',
    'QCommonStyle': 'PySide6.QtWidgets', 'QCompleter': 'PySide6.QtWidgets',
    'QDataWidgetMapper': 'PySide6.QtWidgets', 'QDateEdit': 'PySide6.QtWidgets',
    'QDateTimeEdit': 'PySide6.QtWidgets', 'QDial': 'PySide6.QtWidgets',
    'QDialog': 'PySide6.QtWidgets', 'QDialogButtonBox': 'PySide6.QtWidgets',
    'QDockWidget': 'PySide6.QtWidgets', 'QDoubleSpinBox': 'PySide6.QtWidgets',
    'QErrorMessage': 'PySide6.QtWidgets', 'QFileDialog': 'PySide6.QtWidgets',
    'QFileIconProvider': 'PySide6.QtWidgets', 'QFocusFrame': 'PySide6.QtWidgets',
    'QFontComboBox': 'PySide6.QtWidgets', 'QFontDialog': 'PySide6.QtWidgets',
    'QFormLayout': 'PySide6.QtWidgets', 'QFrame': 'PySide6.QtWidgets',
    'QGesture': 'PySide6.QtWidgets', 'QGestureEvent': 'PySide6.QtWidgets',
    'QGestureRecognizer': 'PySide6.QtWidgets', 'QGraphicsAnchor': 'PySide6.QtWidgets',
    'QGraphicsAnchorLayout': 'PySide6.QtWidgets', 'QGraphicsBlurEffect': 'PySide6.QtWidgets',
    'QGraphicsColorizeEffect': 'PySide6.QtWidgets', 'QGraphicsDropShadowEffect': 'PySide6.QtWidgets',
    'QGraphicsEffect': 'PySide6.QtWidgets', 'QGraphicsEllipseItem': 'PySide6.QtWidgets',
    'QGraphicsGridLayout': 'PySide6.QtWidgets', 'QGraphicsItem': 'PySide6.QtWidgets',
    'QGraphicsItemGroup': 'PySide6.QtWidgets', 'QGraphicsLayout': 'PySide6.QtWidgets',
    'QGraphicsLayoutItem': 'PySide6.QtWidgets', 'QGraphicsLineItem': 'PySide6.QtWidgets',
    'QGraphicsLinearLayout': 'PySide6.QtWidgets', 'QGraphicsObject': 'PySide6.QtWidgets',
    'QGraphicsOpacityEffect': 'PySide6.QtWidgets', 'QGraphicsPathItem': 'PySide6.QtWidgets',
    'QGraphicsPixmapItem': 'PySide6.QtWidgets', 'QGraphicsPolygonItem': 'PySide6.QtWidgets',
    'QGraphicsProxyWidget': 'PySide6.QtWidgets', 'QGraphicsRectItem': 'PySide6.QtWidgets',
    'QGraphicsRotation': 'PySide6.QtWidgets', 'QGraphicsScale': 'PySide6.QtWidgets',
    'QGraphicsScene': 'PySide6.QtWidgets', 'QGraphicsSceneContextMenuEvent': 'PySide6.QtWidgets',
    'QGraphicsSceneDragDropEvent': 'PySide6.QtWidgets', 'QGraphicsSceneEvent': 'PySide6.QtWidgets',
    'QGraphicsSceneHelpEvent': 'PySide6.QtWidgets', 'QGraphicsSceneHoverEvent': 'PySide6.QtWidgets',
    'QGraphicsSceneMouseEvent': 'PySide6.QtWidgets', 'QGraphicsSceneMoveEvent': 'PySide6.QtWidgets',
    'QGraphicsSceneResizeEvent': 'PySide6.QtWidgets', 'QGraphicsSceneWheelEvent': 'PySide6.QtWidgets',
    'QGraphicsSimpleTextItem': 'PySide6.QtWidgets', 'QGraphicsTextItem': 'PySide6.QtWidgets',
    'QGraphicsTransform': 'PySide6.QtWidgets', 'QGraphicsView': 'PySide6.QtWidgets',
    'QGraphicsWidget': 'PySide6.QtWidgets', 'QGridLayout': 'PySide6.QtWidgets',
    'QGroupBox': 'PySide6.QtWidgets', 'QHBoxLayout': 'PySide6.QtWidgets',
    'QHeaderView': 'PySide6.QtWidgets', 'QInputDialog': 'PySide6.QtWidgets',
    'QItemDelegate': 'PySide6.QtWidgets', 'QItemEditorCreator': 'PySide6.QtWidgets',
    'QItemEditorCreatorBase': 'PySide6.QtWidgets', 'QItemEditorFactory': 'PySide6.QtWidgets',
    'QKeySequenceEdit': 'PySide6.QtWidgets', 'QLCDNumber': 'PySide6.QtWidgets',
    'QLabel': 'PySide6.QtWidgets', 'QLayout': 'PySide6.QtWidgets',
    'QLayoutItem': 'PySide6.QtWidgets', 'QLineEdit': 'PySide6.QtWidgets',
    'QListView': 'PySide6.QtWidgets', 'QListWidget': 'PySide6.QtWidgets',
    'QListWidgetItem': 'PySide6.QtWidgets', 'QMainWindow': 'PySide6.QtWidgets',
    'QMdiArea': 'PySide6.QtWidgets', 'QMdiSubWindow': 'PySide6.QtWidgets',
    'QMenu': 'PySide6.QtWidgets', 'QMenuBar': 'PySide6.QtWidgets',
    'QMessageBox': 'PySide6.QtWidgets', 'QPanGesture': 'PySide6.QtWidgets',
    'QPinchGesture': 'PySide6.QtWidgets', 'QPlainTextDocumentLayout': 'PySide6.QtWidgets',
    'QPlainTextEdit': 'PySide6.QtWidgets', 'QProgressBar': 'PySide6.QtWidgets',
    'QProgressDialog': 'PySide6.QtWidgets', 'QProxyStyle': 'PySide6.QtWidgets',
    'QPushButton': 'PySide6.QtWidgets', 'QRadioButton': 'PySide6.QtWidgets',
    'QRhiWidget': 'PySide6.QtWidgets', 'QRubberBand': 'PySide6.QtWidgets',
    'QScrollArea': 'PySide6.QtWidgets', 'QScrollBar': 'PySide6.QtWidgets',
    'QScroller': 'PySide6.QtWidgets', 'QScrollerProperties': 'PySide6.QtWidgets',
    'QSizeGrip': 'PySide6.QtWidgets', 'QSizePolicy': 'PySide6.QtWidgets',
    'QSlider': 'PySide6.QtWidgets', 'QSpacerItem': 'PySide6.QtWidgets',
    'QSpinBox': 'PySide6.QtWidgets', 'QSplashScreen': 'PySide6.QtWidgets',
    'QSplitter': 'PySide6.QtWidgets', 'QSplitterHandle': 'PySide6.QtWidgets',
    'QStackedLayout': 'PySide6.QtWidgets', 'QStackedWidget': 'PySide6.QtWidgets',
    'QStandardItemEditorCreator': 'PySide6.QtWidgets', 'QStatusBar': 'PySide6.QtWidgets',
    'QStyle': 'PySide6.QtWidgets', 'QStyleFactory': 'PySide6.QtWidgets',
    'QStyleHintReturn': 'PySide6.QtWidgets', 'QStyleHintReturnMask': 'PySide6.QtWidgets',
    'QStyleHintReturnVariant': 'PySide6.QtWidgets', 'QStyleOption': 'PySide6.QtWidgets',
    'QStyleOptionButton': 'PySide6.QtWidgets', 'QStyleOptionComboBox': 'PySide6.QtWidgets',
    'QStyleOptionComplex': 'PySide6.QtWidgets', 'QStyleOptionDockWidget': 'PySide6.QtWidgets',
    'QStyleOptionFocusRect': 'PySide6.QtWidgets', 'QStyleOptionFrame': 'PySide6.QtWidgets',
    'QStyleOptionGraphicsItem': 'PySide6.QtWidgets', 'QStyleOptionGroupBox': 'PySide6.QtWidgets',
    'QStyleOptionHeader': 'PySide6.QtWidgets', 'QStyleOptionHeaderV2': 'PySide6.QtWidgets',
    'QStyleOptionMenuItem': 'PySide6.QtWidgets', 'QStyleOptionProgressBar': 'PySide6.QtWidgets',
    'QStyleOptionRubberBand': 'PySide6.QtWidgets', 'QStyleOptionSizeGrip': 'PySide6.QtWidgets',
    'QStyleOptionSlider': 'PySide6.QtWidgets', 'QStyleOptionSpinBox': 'PySide6.QtWidgets',
    'QStyleOptionTab': 'PySide6.QtWidgets', 'QStyleOptionTabBarBase': 'PySide6.QtWidgets',
    'QStyleOptionTabWidgetFrame': 'PySide6.QtWidgets', 'QStyleOptionTitleBar': 'PySide6.QtWidgets',
    'QStyleOptionToolBar': 'PySide6.QtWidgets', 'QStyleOptionToolBox': 'PySide6.QtWidgets',
    'QStyleOptionToolButton': 'PySide6.QtWidgets', 'QStyleOptionViewItem': 'PySide6.QtWidgets',
    'QStylePainter': 'PySide6.QtWidgets', 'QStylePlugin': 'PySide6.QtWidgets',
    'QStyledItemDelegate': 'PySide6.QtWidgets', 'QSwipeGesture': 'PySide6.QtWidgets',
    'QSystemTrayIcon': 'PySide6.QtWidgets', 'QTabBar': 'PySide6.QtWidgets',
    'QTabWidget': 'PySide6.QtWidgets', 'QTableView': 'PySide6.QtWidgets',
    'QTableWidget': 'PySide6.QtWidgets', 'QTableWidgetItem': 'PySide6.QtWidgets',
    'QTableWidgetSelectionRange': 'PySide6.QtWidgets', 'QTapAndHoldGesture': 'PySide6.QtWidgets',
    'QTapGesture': 'PySide6.QtWidgets', 'QTextBrowser': 'PySide6.QtWidgets',
    'QTextEdit': 'PySide6.QtWidgets', 'QTimeEdit': 'PySide6.QtWidgets',
    'QToolBar': 'PySide6.QtWidgets', 'QToolBox': 'PySide6.QtWidgets',
    'QToolButton': 'PySide6.QtWidgets', 'QToolTip': 'PySide6.QtWidgets',
    'QTreeView': 'PySide6.QtWidgets', 'QTreeWidget': 'PySide6.QtWidgets',
    'QTreeWidgetItem': 'PySide6.QtWidgets', 'QTreeWidgetItemIterator': 'PySide6.QtWidgets',
    'QUndoView': 'PySide6.QtWidgets', 'QVBoxLayout': 'PySide6.QtWidgets',
    'QWhatsThis': 'PySide6.QtWidgets', 'QWidget': 'PySide6.QtWidgets',
    'QWidgetAction': 'PySide6.QtWidgets', 'QWidgetItem': 'PySide6.QtWidgets',
    'QWizard': 'PySide6.QtWidgets', 'QWizardPage': 'PySide6.QtWidgets'
}



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="pysideup",
    version="1.0.1",
    author="DongHoon Park",
    author_email="donghun94@gmail.com",
    description="A tool for converting PySide2 code to PySide6",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/DongHoonPark/pysideup",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[
        "astor",
    ],
    entry_points={
        'console_scripts': [
            'pysideup=converter:main',
        ],
    },
    include_package_data=True,
)
